<template>
  <div v-if="!item.hidden">
    <template v-if="hasOneShowingChild(item.children, item) && (!onlyOneChild.children || onlyOneChild.noShowingChildren) && !item.alwaysShow">
      <app-link v-if="onlyOneChild.meta" :to="onlyOneChild.path">
        <el-menu-item :index="onlyOneChild.path" :class="{ 'submenu-title-noDropdown': !isNest }">
          <svg-icon :icon-class="onlyOneChild.meta.icon || (item.meta && item.meta.icon)"/>
          <template #title><span class="menu-title" :title="hasTitle(onlyOneChild.meta.title)">{{ onlyOneChild.meta.title }}</span></template>
        </el-menu-item>
      </app-link>
    </template>

    <el-sub-menu v-else ref="subMenu" :index="item.path" teleported>
      <template v-if="item.meta" #title>
        <svg-icon :icon-class="item.meta && item.meta.icon"/>
        <span class="menu-title" :title="hasTitle(item.meta.title)">{{ item.meta.title }}</span>
      </template>
      <sidebar-item
        v-for="(child, index) in item.children"
        :key="child.path + index"
        :is-nest="true"
        :item="child"
        :base-path="resolvePath(child.path)"
        class="nest-menu"
      />
    </el-sub-menu>
  </div>
</template>

<script setup>
import { isExternal } from '@/utils/validate'
import AppLink from './Link'
import { getNormalPath } from '@/utils/ruoyi'
import { onMounted } from 'vue';

const props = defineProps({
  // route object
  item: {
    type: Object,
    required: true
  },
  isNest: {
    type: Boolean,
    default: false
  },
  basePath: {
    type: String,
    default: ''
  }
})

const onlyOneChild = ref({});

function hasOneShowingChild(children = [], parent) {
  if (!children) {
    children = [];
  }
  const showingChildren = children.filter(item => {
    if (item.hidden) {
      return false
    } else {
      // Temp set(will be used if only has one showing child)
      onlyOneChild.value = item
      return true
    }
  })

  // When there is only one child router, the child router is displayed by default
  if (showingChildren.length === 1) {
    return true
  }

  // Show parent if there are no child router to display
  if (showingChildren.length === 0) {
    // console.log(777, { ...parent , noShowingChildren: true })
    onlyOneChild.value = { ...parent, noShowingChildren: true }
    return true
  }

  return false
};

function resolvePath(routePath, routeQuery) {
  //验证是否是"https://"、"http://"、"mailto:"、"tel:" 开头的地址
  if (isExternal(routePath)) {
    // console.log(1111, routePath)
    return routePath
  }
  //props.basePath 是否是一个外部路径，如果是，则直接返回 props.basePath
  if (isExternal(props.basePath)) {
    // console.log(2222, props.basePath)
    return props.basePath
  }
  //验证是否是app-link的地址，直接跳转
  if (routeQuery) {
    let query = JSON.parse(routeQuery);
    return { path: getNormalPath(props.basePath + '/' + routePath), query: query }
  }
  //getNormalPath用来规范化路径，去除多余的斜杠
 // console.log(4444, getNormalPath(props.basePath + '/' + routePath))
  return getNormalPath(props.basePath + '/' + routePath)
  // return props.basePath || routePath
}

//规范标题显示长度不超过5
function hasTitle(title){
  if (title.length > 5) {
    return title;
  } else {
    return "";
  }
}
onMounted(()=>{
  // console.log('菜单图标',props.item)
})
</script>
